//********************************************************************
//*** ResourcePool/SQL/RTSQLExecute.cc
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: RTSQLExecute.cc,v 1.27 2009-05-02 22:17:15 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#include "config.h"
#include "ResourcePool/SQL/ResourcePool.hh"
#include "ResourcePool/SQL/RTSQLExecute.hh"
#include "ResourcePool/SQL/RTSQLExecute_Impl.hh"

#include <iostream>
#include <sstream>

namespace fatalmind {
namespace SQL {

template<class TM>
struct SQLExecuteCommandSelector {
	typedef RTSQLExecute_Impl<TM> Impl;
	typedef RTSQLExecute<TM> RTC;

	template<class PT>
	struct Specialized {
		typedef RTSQLExecute_SpecializedImpl<
			  TM
			, RTSQLExecute_Impl
			, PT
			, SQLCommandWrapper<typename PT::command_t::SQLExecute, TM, RTSQLExecute<TM> >
			, RTSQLExecute<TM>
		> Impl;
	};
};

template<class TM>
RTSQLExecute<TM>::RTSQLExecute(const ResourcePool<ResourceType<TM> >& p, const SQLStatement& a_sql)
: _realSQLExecute(
	RTSQLExecute_Impl<TM>::template newRealCommand<
		SQLExecuteCommandSelector<TM>
	>(
		  Command<ResourceType<TM> >::getFactory(p).getDatabaseType()
		, *this
		, a_sql
	)
)
{
}

template<class TM>
RTSQLExecute<TM>::RTSQLExecute(const RTSQLExecute<TM>& rho) 
: _realSQLExecute(rho._realSQLExecute->template clone<RTSQLExecute_Impl<TM> >())
{
}

template<class TM>
RTSQLExecute<TM>::~RTSQLExecute() {
}

template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const char& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}
template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const signed char& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}
template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const unsigned char& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}

template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const short int& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}
template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const unsigned short int& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}
template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const int& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}
template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const unsigned int& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}

template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const long int& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}

template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const unsigned long int& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}

template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const float& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}
template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const double& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}
template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const long double& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}
template<class TM>
void RTSQLExecute<TM>::bind(const unsigned int pos, const std::string& val, bool isnull) {
        _realSQLExecute->bind(pos, val, isnull);
}


template<class TM>
Clone* RTSQLExecute<TM>::DoClone() const {
	return new RTSQLExecute<TM>(*this);
}

template<class TM>
const Clone* RTSQLExecute<TM>::getPlainSpecializedCommand() const {
	return _realSQLExecute->getPlainSpecializedCommand();
}

template<class TM>
void RTSQLExecute<TM>::clearParameters() {
	_realSQLExecute->clearParameters();
}

template<class TM>
void RTSQLExecute<TM>::execute(typename ResourceType<TM>::resource_t& hand) {
	_realSQLExecute->execute(hand);
}

template<class TM>
void RTSQLExecute<TM>::outputoperator(std::ostream& s) const {
	s << "(RP)";
	_realSQLExecute->outputoperator(s);
}

template class RTSQLExecute<DefaultThreadedModel >;

} // namespace SQL
} // namespace fatalmind
