//********************************************************************
//*** ResourcePool/SQL/RTSQLExecute.t.cc
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: RTSQLExecute.t.cc,v 1.12 2009-05-02 18:47:19 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#include "t/main.hh"
#include "config.h"
#include "ResourcePool/ResourcePool.hh"
#include "ResourcePool/SQL/ResourcePool.hh"

#include "testconfig.cc"

#include "../SQL/SQLExecute.t.cc"

#ifdef RESOURCEPOOL_HAVE_ORACLE
std::auto_ptr<RP> oci9_p;
#endif 
#ifdef RESOURCEPOOL_HAVE_MYSQL
std::auto_ptr<RP> mysql3_p;
#endif

void INIT_SQL_SQLExecute() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	oci9_p.reset(new RP(getFactory("oci:" + getOracleLogon())));	
	test_SQLExecute_init(*oci9_p);
#endif
#ifdef RESOURCEPOOL_HAVE_MYSQL
	mysql3_p.reset(new RP(getFactory("mysql:" + getMysqlLogon())));	
	test_SQLExecute_init(*mysql3_p);
#endif
}

void TEST_SQL_OCI9_SQLExecute_insert() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_SQLExecute_one(*oci9_p);
#endif
}
void TEST_SQL_OCI9_SQLExecute_insert_two() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_SQLExecute_two(*oci9_p);
#endif
}
void TEST_SQL_OCI9_SQLExecute_insert_three() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_SQLExecute_three(*oci9_p);
#endif
}
void TEST_PERF_SQL_OCI9_SQLExecute_massbind() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_perf_SQLExecute_massbind(*oci9_p);
#endif
}
void TEST_PERF_SQL_OCI9_SQLExecute_insert() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_perf_SQLExecute_insert(*oci9_p);
#endif
}
void TEST_PERF_SQL_OCI9_SQLExecute_insert_outer() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_perf_SQLExecute_insert_outer(*oci9_p);
#endif
}
void TEST_PERF_SQL_OCI9_SQLExecute_update_outer() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_perf_SQLExecute_update_outer(*oci9_p);
#endif
}
void TEST_SQL_OCI9_SQLExecute_insert_fail() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_SQLExecute_fail(*oci9_p);
#endif
}

void TEST_SQL_OCI9_SQLExecute_output() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_SQLExecute_output(*oci9_p);
#endif
}

void TEST_SQL_MYSQL3_SQLExecute_insert() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_SQLExecute_one(*mysql3_p);
#endif
}
void TEST_SQL_MYSQL3_SQLExecute_insert_two() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_SQLExecute_two(*mysql3_p);
#endif
}
void TEST_SQL_MYSQL3_SQLExecute_insert_three() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_SQLExecute_three(*mysql3_p);
#endif
}
void TEST_PERF_SQL_MYSQL3_SQLExecute_massbind() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_perf_SQLExecute_massbind(*mysql3_p);
#endif
}
void TEST_PERF_SQL_MYSQL3_SQLExecute_insert() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_perf_SQLExecute_insert(*mysql3_p);
#endif
}
void TEST_PERF_SQL_MYSQL3_SQLExecute_insert_outer() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_perf_SQLExecute_insert_outer(*mysql3_p);
#endif
}
void TEST_PERF_SQL_MYSQL3_SQLExecute_update_outer() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_perf_SQLExecute_update_outer(*mysql3_p);
#endif
}
void TEST_SQL_MYSQL3_SQLExecute_insert_fail() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_SQLExecute_fail(*mysql3_p);
#endif
}
void TEST_SQL_MYSQL3_SQLExecute_output() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_SQLExecute_output(*mysql3_p);
#endif
}
void CLEANUP_SQL_SQLExecute() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	drop(*oci9_p);
#endif
#ifdef RESOURCEPOOL_HAVE_MYSQL
	drop(*mysql3_p);
#endif
}

