//********************************************************************
//*** ResourcePool/SQL/RTSQLSelect.t.cc
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: RTSQLSelect.t.cc,v 1.9 2009-05-02 18:47:19 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#include "t/main.hh"
#include "config.h"
#include "ResourcePool/ResourcePool.hh"
#include "ResourcePool/SQL/ResourcePool.hh"

#include "testconfig.cc"

#include "SQLSelect.t.cc"

#ifdef RESOURCEPOOL_HAVE_ORACLE
std::auto_ptr<RP> oci9_rp;
#endif
#ifdef RESOURCEPOOL_HAVE_MYSQL
std::auto_ptr<RP> mysql3_rp;
#endif

void INIT_SQL_SQLSelect() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	oci9_rp.reset(new RP(getFactory("oci9:" + getOracleLogon())));
	test_SQLSelect_init(*oci9_rp);
#endif
#ifdef RESOURCEPOOL_HAVE_MYSQL
	mysql3_rp.reset(new RP(getFactory("mysql3:" + getMysqlLogon())));
	test_SQLSelect_init(*mysql3_rp);
#endif
}


void TEST_SQL_OCI9_SQLSelect_all() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_SQLSelect_one(*oci9_rp);
#endif
}

void TEST_PERF_OCI9_SQL_SQLSelect_all() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_perf_SQLSelect_all(*oci9_rp);
#endif
}

void TEST_PERF_OCI9_SQL_SQLSelect_ten() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_perf_SQLSelect_ten(*oci9_rp);
#endif
}

void TEST_PERF_OCI9_SQL_SQLSelect_one() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_perf_SQLSelect_one(*oci9_rp);
#endif
}

void TEST_OCI9_SQL_SQLSelect_output() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_SQLSelect_output(*oci9_rp);
#endif
}


void TEST_SQL_MYSQL3_SQLSelect_all() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_SQLSelect_one(*mysql3_rp);
#endif
}

void TEST_PERF_MYSQL3_SQL_SQLSelect_all() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_perf_SQLSelect_all(*mysql3_rp);
#endif
}

void TEST_PERF_MYSQL3_SQL_SQLSelect_ten() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_perf_SQLSelect_ten(*mysql3_rp);
#endif
}

/* the SQL string is not mysql aware */
void x_TEST_PERF_MYSQL3_SQL_SQLSelect_one() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_perf_SQLSelect_one(*mysql3_rp);
#endif
}


void TEST_MYSQL3_SQL_SQLSelect_output() {
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_SQLSelect_output((*mysql3_rp));
#endif
}



void CLEANUP_SQL_SQLSelect() {
#ifdef RESOURCEPOOL_HAVE_ORACLE
	test_SQLSelect_cleanup(*oci9_rp);
#endif
#ifdef RESOURCEPOOL_HAVE_MYSQL
	test_SQLSelect_cleanup(*mysql3_rp);
#endif
}
