//********************************************************************
//*** ResourcePool/SQL/SQLException.hh
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: SQLException.hh,v 1.13 2009-05-04 13:20:43 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of 
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#ifndef RESOURCEPOOL_SQL_SQLException_HH
#define RESOURCEPOOL_SQL_SQLException_HH

#ifndef INCLUDED_EXCEPTIONS_HH
#include "Exceptions/Exception.hh"
#endif

#include "SQLStatement.hh"

namespace fatalmind {
namespace SQL {

/**
 * General exception to be thrown by SQL commands.
 */
class SQLException: virtual public Exception {
	public:
		SQLException(const std::string& msg
			, const std::string&  sqlstate // confirming to X/Open
			, const std::string&  sql
			, const bool          failover // Should this exception cause an failover in ResourcPool?
		):Exception(getFullMessage(msg, sql))
		, _sqlstate(sqlstate)
		, _sql(sql)
		, _failover(failover)
		{
		}

		SQLException(const std::string& msg
			, const std::string&  sqlstate // confirming to X/Open
			, const SQLStatement& sqlstm   // the SQL statement which caused the exception
			, const bool          failover // Should this exception cause an failover in ResourcPool?
		):Exception(getFullMessage(msg, sqlstm.getSQL()))
		, _sqlstate(sqlstate)
		, _sql(sqlstm.getSQL())
		, _failover(failover)
		{
		}

		static std::string getFullMessage(const std::string& message, const std::string& sql) {
			std::string rv(message);
			rv += " with SQL: " + sql; // ref or getSQL is ok here
			return rv;
		}

		const std::string& getSQL() const throw() {
			return _sql;
		}

		bool isFailover() const throw() {
			return _failover;
		}

		const std::string& getSQLState() const throw() {
			return _sqlstate;
		}
		
		bool isSQLState(const char* const c) const {
			return !_sqlstate.compare(c);
		}

		const std::string getSQLStateClass() const {
			return _sqlstate.substr(0,2);
		}

		bool isSQLStateClass(const std::string& c) const {
			return !_sqlstate.compare(0, 2, c, 0, 2);
		}
			
		bool isSQLStateClass(const char* const c) const {
			return !_sqlstate.compare(0, 2, c, 0, 2);
		}

	private:
		const std::string  _sqlstate;
		const std::string  _sql;
		const bool         _failover;
}; // class SQLException

} // namespace SQL
} // namespace fatalmind

#endif
