//********************************************************************
//*** ResourcePool/mysql/Factory.hh
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: Factory.hh,v 1.17 2009-05-02 18:47:19 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */


#ifndef RESOURCEPOOL_MYSQL_FACTORY_HH
#define RESOURCEPOOL_MYSQL_FACTORY_HH

#ifndef RESOURCEPOOL_MYSQL_RESOURCE_HH
#include "Resource.hh"
#endif

#include "ResourcePool/SQL/SQLFactoryInterface.hh"
#include "ResourcePool/ResourcePoolStreamLogger.hh"

#include <string>

namespace fatalmind {

/**
 * 
 * Please consider the following Event arguments:
 *
 * \b EXECUTE
 * \li \c CRITICAL \c WARNING - Means that something which mysql reports as warning is handled by ResourcePool as error.
 * 
 * \b FETCH
 * \li \c NO \c DATA - a SQLSelectRow command did not return any data
 * \li \c MORE \c DATA - a SQLSelectRow command did return more then one row
 */
class mysqlFactory : public SQL::SQLFactoryInterface {
	typedef SQL::SQLFactoryInterface super;
	public:
		mysqlFactory(const std::string& host
			, const std::string& user
			, const std::string& pass
			, const std::string& db
			, unsigned int port = 3306
			, const std::string& sock = ""
			, ResourcePoolEventObserver& e = ResourcePoolStreamLogger::defaultLogger
		);
		mysqlFactory(const std::string& connect, ResourcePoolEventObserver& e = ResourcePoolStreamLogger::defaultLogger);

		using super::databaseType_t;
		databaseType_t getDatabaseType() const {
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
			return MYSQLTX;
#else
			return MYSQL;
#endif
		};
	
		mysqlResource* create_resource() const;
			
	protected:
		virtual Clone* DoClone() const;

	private:
		std::string _host;
		std::string _user;
		std::string _pass;
		std::string _db;
		unsigned int _port;
		const std::string _sock;
};

} // namespace fatalmind
#endif
