//********************************************************************
//*** ResourcePool/mysql/Transaction.t.cc
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: Transaction.t.cc,v 1.8 2009-05-02 22:17:15 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#include <memory>
#include "ResourcePool/mysql/ResourcePool.hh"
#include "t/main.hh"

using namespace std;
using namespace fatalmind;

typedef ResourcePool<ResourceType::mysql> RP;

#include "testconfig.cc"

#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
#include "../SQL/SQLTransaction.t.cc"
#endif

std::auto_ptr<RP> _rp;
void test_init()
{
    if (_rp.get() == 0) {
        ResourcePoolOptions opt;
        opt.setMaxExecTry(1);
        _rp.reset(new RP(getFactory(), opt));
    }
}

void INIT_mysql_Transaction() 
{
	test_init();
	init(*_rp);	
	RP::Commands::SQLExecute init("insert into hirsch (id, ukn) values (?, ?)");
	for (int i = 0; i < 300; ++i) {
		init.bind(0, i);
		init.bind(1, "hirschig");
		_rp->execute(init);
	}
}

void TEST_mysql_Transaction_one()
{
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_init_me(*_rp);
	trans_test_ok(*_rp, 0);
#else
	throw SkippedException("No Transactions");
#endif
}

void TEST_PERF_mysql_Transaction_one()
{
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_init_me(*_rp);
	for (int i = 0; i < 100; ++i) {
		trans_test_ok(*_rp, i);
	}
#else
	throw SkippedException("No Transactions");
#endif
}

void TEST_PERF_mysql_Transaction_one_cached()
{
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_init_me(*_rp);
	for (int i = 0; i < 100; ++i) {
		trans_test_ok(*_rp, i, true);
	}
#else
	throw SkippedException("No Transactions");
#endif
}

void TEST_mysql_Transaction_rec()
{
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_rec(*_rp);
#else
	throw SkippedException("No Transactions");
#endif
}

void TEST_mysql_Transaction_rec_fail()
{
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_rec_fail(*_rp);
#else
	throw SkippedException("No Transactions");
#endif
}

void TEST_mysql_Transaction_fail()
{
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_init_me(*_rp);
	trans_test_fail(*_rp, 0);
#else
	throw SkippedException("No Transactions");
#endif
}

void TEST_PERF_mysql_Transaction_fail()
{
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_init_me(*_rp);
	for (int i = 0; i < 100; ++i) {
		trans_test_fail(*_rp, i);
	}
#else
	throw SkippedException("No Transactions");
#endif
}

void TEST_PERF_mysql_Transaction_fail_cached()
{
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_init_me(*_rp);
	for (int i = 0; i < 100; ++i) {
		trans_test_fail(*_rp, i, true);
	}
#else
	throw SkippedException("No Transactions");
#endif
}


void TEST_mysql_Transaction_fail_rec() {
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_init_me(*_rp);
	trans_test_fail_rec(*_rp, 0);
#else
	throw SkippedException("No Transactions");
#endif
}

void TEST_PERF_mysql_Transaction_fail_rec() {
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_init_me(*_rp);
	for (int i = 0; i < 100; ++i) {
		trans_test_fail_rec(*_rp, i);
	}
#else
	throw SkippedException("No Transactions");
#endif
}

void TEST_PERF_mysql_Transaction_fail_rec_ca() {
#ifdef RESOURCEPOOL_HAVE_MYSQL_TRANSACTIONS
	SQLTransaction_init_me(*_rp);
	for (int i = 0; i < 100; ++i) {
		trans_test_fail_rec(*_rp, i, true);
	}
#else
	throw SkippedException("No Transactions");
#endif
}
