//********************************************************************
//*** ResourcePool/oracle/OracleException.cc
//*** Copyright (c) 2003-2009 by Markus Winand <mws@fatalmind.com>
//*** $Id: OracleException.cc,v 1.28 2009-03-17 19:13:54 mws Exp $
//********************************************************************
/*
This file is part of ResourcePool.

ResourcePool is free software; you can redistribute it
and/or modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2 of 
the License, or (at your option) any later version.

ResourcePool is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied warranty
of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with ResourcePool; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
02111-1307  USA */

#ifndef RESOURCEPOOL_ORACLE_ORACLEEXCEPTION_HH
#include "OracleException.hh"
#endif

#include <sstream>

namespace fatalmind {

OracleException::OracleException(const OracleException& rho) 
: Exception(rho) // virtual base class
, SQLException(rho)
, _errornumber(rho._errornumber)
, errorcode(rho.errorcode)
{
}

OracleException::OracleException(
	  const std::string& msg
	, const std::string& ec
	, const int errornumber
	, const SQL::SQLStatement& sqlstm
):Exception(msg)
, SQLException(msg, mapORAtoXOPEN(errornumber), sqlstm, true)
, _errornumber(errornumber)
, errorcode(errorcode)
{
}

const char* OracleException::mapORAtoXOPEN(const int errornumber)
{
	switch(errornumber) {
		case 1013: // user requested cancelation of current operation
			return "57014"; 
			break;
		case 1400: 
		case 1401:
		case 1407:
		case 1: return "23000"; break; // integrity constraint violation
		case 1004:
		case 1005: return "08004";
		case 1756: return "07000";
		case 1006: 
		case 1007: 
		case 1062:
		case 24374:
		case 1008: return "07001"; // not all variables bound
		case 1036: return "07001"; // "illegal variable name/number"
		case 1017: return "28000"; // invalid authorization
		case 1041: return "42000"; // syntax error
		case 1402: return "44000"; // with check
		case 1405: return "22002"; // indicator variable missing
		case 1406: return "01004"; // trancated
		case 1422:  // exact fetch returns more than requested number of row s
		case 12899: // value too large for column
			return "22000";  // data exception
		case 999999: return "02000";
	}
	if (errornumber >= 900 && errornumber <= 999) {
		return "07000"; // dynamic sql error
	}
	return "08000"; // connection error
}

NFOOracleException::NFOOracleException(
	  const std::string& msg
	, const std::string& ec
	, const int errornumber
	, const SQL::SQLStatement& sqlstm
):Exception(msg) // virtual base class
, SQLException(msg, mapORAtoXOPEN(errornumber), sqlstm, false)
, OracleException(msg, ec, errornumber, sqlstm)
, NoFailoverException(msg)
{
}

} // namespace fatalmind

